@@ -19,29 +19,29 @@ comp.test <- function(x, ina, test = "james", R = 0, ncores = 1, graph = FALSE)
   ## ncores is the number of cores you want to use
   ## requires(doParallel)
   ## if graph is TRUE, the bootstrap statics are plotted
-  y <- alfa(x, 1)$aff  ## the alpha-transformation with alpha = 1
+  y <- Compositional::alfa(x, 1)$aff  ## the alpha-transformation with alpha = 1
   ina <- as.numeric(ina)  ## the group indicator variable
   k <- max(ina)  ## the number of groups
   ## default value in the case of MANOVA and bad specification of test
   ## is the James MANOVA
-  if ( k > 2 & ( test != "maovjames" || test != "maov" ) )   result <- Compositional::maovjames(x, ina)
+  if ( k > 2 & ( test != "maovjames" || test != "maov" ) )   result <- mvhtests::maovjames(x, ina)
   ## multi-sample case
   if (k > 2) {
 
     if (test == "maov") {
-      result <- Compositional::maov(x, ina)
-    } else if ( test == "maovjames" )  result <- Compositional::maovjames(x, ina)
+      result <- mvhtests::maov(x, ina)
+    } else if ( test == "maovjames" )  result <- mvhtests::maovjames(x, ina)
     ## two sample case
   } else if ( k == 2 ) {
 
     if ( test == "hotel" ) {
-      result <- Compositional::hotel2T2(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
+      result <- mvhtests::hotel2T2(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
     } else if ( test == "james" ) {
-      result <- Compositional::james(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
+      result <- mvhtests::james(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
     } else if ( test == "el" ) {
-      result <- Compositional::el.test2(y[ina == 1, ], y[ina == 2, ], R = R, ncores = ncores, graph = graph)
+      result <- mvhtests::el.test2(y[ina == 1, ], y[ina == 2, ], R = R, ncores = ncores, graph = graph)
     } else if ( test == "eel" ) {
-      result <- Compositional::eel.test2(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
+      result <- mvhtests::eel.test2(y[ina == 1, ], y[ina == 2, ], R = R, graph = graph)
     }
   }
   result
